@@ -164,8 +164,12 @@ var Nautilus = (function() {
     videojs.options.preload = "auto";
     videojs.options.techOrder = ["html5", "ogvjs"];
     videojs.options.ogvjs = {base: "vendors/ogvjs"};
+    videojs.options.controlBar = {pictureInPictureToggle: false};
     // for some reason, global controls options is not working
-    window.videojs_options = {controls: true, preload: 'auto', crossorigin: true};
+    window.videojs_options = {controls: true,
+                              preload: 'auto', 
+                              crossorigin: true,
+                              controlBar: {pictureInPictureToggle: false}};
   };
 
   Nautilus.prototype.init_database = function () {
